@@ -13,6 +13,7 @@
 
 #include <KAboutData>
 #include <KLocalizedString>
+#include <KCrash>
 
 #include "kfinddlg.h"
 #include "kfind_version.h"
@@ -46,11 +47,15 @@ int main(int argc, char **argv)
     aboutData.setTranslator(i18nc("NAME OF TRANSLATORS", "Your names"), i18nc("EMAIL OF TRANSLATORS", "Your emails"));
     QCommandLineParser parser;
     KAboutData::setApplicationData(aboutData);
+    KCrash::initialize();
     parser.addOption(QCommandLineOption(QStringList() <<  QStringLiteral("+[searchpath]"), i18n("Path(s) to search")));
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
     aboutData.processCommandLine(&parser);
+
+    KCrash::initialize();
+
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("kfind")));
     QUrl url;
     if (!parser.positionalArguments().isEmpty())
